Face à Face Montreal, Quebec March 25th 2006 3R+F 18 players François de Champlain Deck Name: Godzilla This deck is a mass bruise bleed deck. The secret is to threaten your predator (even torporise a few of his minions) and keep him out of your way right from the beginning (with you first hatchling): you have enough ousting power. After that he'll leave you alone. That's what the haven uncovered and bum's rush are for. This deck attracts a lot of attention so don't get greedy. Split table VPs as soon as you can otherwise the table will team against you. Divide to better reign ! The core of this deck is the 42 combat cards. Do not go under ! As for the hatchlings, 14 is a good number... Especially with the added thin-blooded seers. 13 masters and 5 trifles is a lot. . Fame and Anarch troublemaker were very useful. Could remove some stealth and add more rockhearts. Ps: took the risks of being voted out by cards like anarchist uprising but preferred the tributes instead of the DI s. Crypt (12 cards, min=10, max=21, avg=3.92) ------------------------------------------ 2x Obsidian 5 VIS for pot Gargoyle:2 2x Fidus, The Shrunken Beast 4 for tha vis Gargoyle:2 2x Erinyi 3 pot vis Gargoyle:2 1x Saxum, Master of Slaves 6 FOR VIS pot pre Gargoyle:2 1x Luma, Stone Beauty 5 FOR aus pot vis Gargoyle:2 1x Pugfar 5 POT aus for vis Gargoyle:2 1x Ehrich Weiss 3 dom tha Tremere:3 1x Almiro Suarez 2 aus Tremere:3 1x Mustafa Rahman 2 dom Tremere:2 Library (91 cards) Master (18; 5 trifle) 1x Anarch Troublemaker 1x Coven, The 1x Creepshow Casino 1x Fame 1x Giant's Blood 2x Haven Uncovered 2x Jake Washington 4x Life in the City 1x Sunset Strip, Hollywood 4x Tribute to the Master Action (24) 5x Bum's Rush 14x Hatchling 5x Thin-Blooded Seer Action Modifier (5) 5x Skin of the Chameleon Combat (44) 8x Crawling Chamber 15x Raking Talons 8x Rockheart 13x Stonestrength